@@ -1,7 +1,8 @@
 import requests
 
 from ddipy import constants
-from ddipy.constants import DATA_NOT_FOUND
+from ddipy.commons import Dataset, DataSetResult, BatchDataset
+from ddipy.constants import DATA_NOT_FOUND, HEADERS, MISSING_PARAMETER
 from ddipy.ddi_utils import VerifyUtils, BadRequest
 
 
@@ -28,10 +29,8 @@ class DatasetClient:
             "sourceUrl": source_url,
             "name": name
         }
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] =  access_token
         res = requests.post(constants.MERGE_URL, params=request_params, headers=tokened_header)
         return res
 
@@ -46,19 +45,17 @@ class DatasetClient:
     # todo
     @staticmethod
     def unmerge(merge_candidates, access_token):
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] = access_token
+
         res = requests.post(constants.UNMERGE_URL, params=merge_candidates, headers=tokened_header)
         return res
 
     @staticmethod
     def get_merge_candidates(start, size, access_token):
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] = access_token
         res = requests.get(constants.MERGE_CANDIDATE_URL, params={
             "start": start,
             "size": size
@@ -83,19 +80,15 @@ class DatasetClient:
             "sourceUrl": source_url,
             "name": name
         }
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] = access_token
         res = requests.post(constants.MULTIOMICS_MERGE_URL, params=request_params, headers=tokened_header)
         return res
 
     @staticmethod
     def get_allmerged(access_token):
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] = access_token
         res = requests.get(constants.ALL_MERGE_URL, headers=tokened_header)
         return res
 
@@ -103,7 +96,7 @@ class DatasetClient:
     def get_dataset_by_url(url):
 
         if not url:
-            return VerifyUtils.empty_param_error("url")
+            raise BadRequest("missing parameter url", MISSING_PARAMETER, payload=None)
 
         res = requests.post(constants.DATASET_URL + "/getDatasetByUrl", params={
             "url": url
@@ -117,10 +110,9 @@ class DatasetClient:
 
     @staticmethod
     def get_merge_candidate_count(access_token):
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] = access_token
+
         res = requests.get(constants.MERGE_CANDIDATE_COUNT_URL, headers=tokened_header)
         return res
 
@@ -142,48 +134,50 @@ class DatasetClient:
             "sourceUrl": source_url,
             "name": name
         }
-        tokened_header = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, "
-                                        "like Gecko) "
-                                        "Chrome/54.0.2840.99 Safari/537.36",
-                          "x-auth-token": access_token}
+        tokened_header = HEADERS.copy()
+        tokened_header["x-auth-token"] = access_token
+
         res = requests.post(constants.SKIP_MERGE_URL, params=request_params, headers=tokened_header)
         return res
 
     @staticmethod
-    def get_dataset_details(domain, accession, debug=False):
-        if not domain:
-            return VerifyUtils.empty_param_error("domain")
+    def get_dataset_details(database, accession):
+        if not database:
+            raise BadRequest("missing parameter database", MISSING_PARAMETER, payload=None)
 
         if not accession:
-            return VerifyUtils.empty_param_error("accession")
+            raise BadRequest("missing parameter accession", MISSING_PARAMETER, payload=None)
 
-        res = requests.get(constants.DATASET_URL + "/" + domain + "/" + accession, params={
-            "debug": debug
-        }, headers=constants.HEADERS)
+        res = requests.get(constants.DATASET_URL + "/" + database + "/" + accession, headers=constants.HEADERS)
 
         if res.status_code != 200:
-            raise BadRequest("The request dataset accession {} and database {} thrown connection error".format(accession, domain), res.status_code, payload= None)
-        elif res.status_code == 200 and res.json()['accession'] == "None":
-            raise BadRequest( "The request dataset accession {} and database {} was not found in the server".format(accession, domain), DATA_NOT_FOUND, payload=None)
-        return res.json()
+            raise BadRequest("The request dataset accession {} and database {} thrown connection error".format(accession, database), res.status_code, payload=None)
+
+        dataset = Dataset.get_object_from_json(res.json())
+
+        return dataset
 
     @staticmethod
-    def get_dataset_files(domain, accession, position):
-        if not domain:
-            return VerifyUtils.empty_param_error("domain")
+    def get_dataset_files(database, accession, position):
+        if not database:
+            raise BadRequest("missing parameter database", MISSING_PARAMETER, payload=None)
 
         if not accession:
-            return VerifyUtils.empty_param_error("accession")
+            raise BadRequest("missing parameter accession", MISSING_PARAMETER, payload=None)
 
         if not position:
-            return VerifyUtils.empty_param_error("position")
+            raise BadRequest("missing parameter position", MISSING_PARAMETER, payload=None)
 
-        res = requests.get(constants.DATASET_URL + "/" + domain + "/" + accession + "/files",
+        res = requests.get(constants.DATASET_URL + "/" + database + "/" + accession + "/files",
                            params={
                                "position": position
                            },
                            headers=constants.HEADERS)
-        return res
+        file_links = []
+        if res.json():
+            for file_link in res.json():
+                file_links.append(file_link)
+        return file_links
 
     @staticmethod
     def get_db_dataset_count():
@@ -191,46 +185,47 @@ class DatasetClient:
         return res
 
     @staticmethod
-    def search(query="", sortfield="", order="", start=0, size=20, face_count=20):
+    def search(query, sortfield=None, order=None, start=0, size=20, face_count=20):
         params = {
             "start": start,
             "size": size,
             "faceCount": face_count
         }
-        print(query)
         if not query:
-            return VerifyUtils.empty_param_error("query")
+            raise BadRequest("missing parameter query", MISSING_PARAMETER, payload=None)
         else:
             params.update(query=query)
-        if not query:
-            return VerifyUtils.empty_param_error("sortfield")
-        else:
+        if sortfield:
             params.update(sortfield=sortfield)
-        if not query:
-            return VerifyUtils.empty_param_error("order")
-        else:
+        if order:
             params.update(order=order)
 
         res = requests.get(constants.SEARCH_URL, params=params, headers=constants.HEADERS)
-        return res
+        if res.status_code != 200:
+            raise BadRequest("The request query {} and sortfield {} and order {} thrown connection error".format(query, sortfield, order), res.status_code, payload=None)
+
+        return DataSetResult.get_object_from_json(res.json())
 
     @staticmethod
     def latest(size=20):
         res = requests.get(constants.LATEST_URL, params={
             "size": size
         }, headers=constants.HEADERS)
-        return res
+
+        if res.status_code != 200:
+            raise BadRequest("The request thrown connection error", res.status_code, payload=None)
+        return DataSetResult.get_object_from_json(res.json())
 
     @staticmethod
     def get(acc, database):
         if not acc:
-            return VerifyUtils.empty_param_error("acc")
+            raise BadRequest("missing parameter acc", MISSING_PARAMETER, payload=None)
 
         if not database:
-            return VerifyUtils.empty_param_error("database")
+            raise BadRequest("missing parameter database", MISSING_PARAMETER, payload=None)
 
         res = requests.get(constants.GET_URL, params={
-            "acc": acc,
+            "accession": acc,
             "database": database
         }, headers=constants.HEADERS)
         return res.json()
@@ -238,64 +233,84 @@ class DatasetClient:
     @staticmethod
     def get_similar_by_pubmed(pubmed):
         if not pubmed:
-            return VerifyUtils.empty_param_error("pubmed")
+            raise BadRequest("missing parameter pubmed", MISSING_PARAMETER, payload=None)
 
         res = requests.get(constants.DATASET_URL + "/getSimilarByPubmed", params={
             "pubmed": pubmed
         }, headers=constants.HEADERS)
-        return res
+
+        if res.status_code != 200:
+            raise BadRequest("The request pubmed {} thrown connection error".format(pubmed), res.status_code, payload=None)
+        datasets = []
+        for i in res.json():
+            dataset = Dataset.get_object_from_json(i)
+            datasets.append(dataset)
+        return datasets
 
     @staticmethod
     def batch(acc, database):
         if not acc:
-            return VerifyUtils.empty_param_error("acc")
+            raise BadRequest("missing parameter acc", MISSING_PARAMETER, payload=None)
 
         if not database:
-            return VerifyUtils.empty_param_error("database")
+            raise BadRequest("missing parameter database", MISSING_PARAMETER, payload=None)
 
         res = requests.get(constants.BATCH_URL, params={
-            "acc": acc,
+            "accession": acc,
             "database": database
         }, headers=constants.HEADERS)
-        return res
+
+        if res.status_code != 200:
+            raise BadRequest("The request accession {} and database {} thrown connection error".format(acc, database), res.status_code, payload=None)
+        return BatchDataset.get_object_from_json(res.json())
 
     @staticmethod
     def most_accessed(size=20):
         res = requests.get(constants.MOST_ACCESSED_DATASETS, params={
             "size": size
         }, headers=constants.HEADERS)
-        return res
+
+        if res.status_code != 200:
+            raise BadRequest("The request thrown connection error", res.status_code, payload=None)
+
+        return DataSetResult.get_object_from_json(res.json())
 
     @staticmethod
-    def get_file_links(acc, database):
-        if not acc:
-            return VerifyUtils.empty_param_error("acc")
+    def get_file_links(accession, database):
+        if not accession:
+            raise BadRequest("missing parameter accession", MISSING_PARAMETER, payload=None)
 
         if not database:
-            return VerifyUtils.empty_param_error("database")
+            raise BadRequest("missing parameter database", MISSING_PARAMETER, payload=None)
 
         res = requests.get(constants.FILE_LINKS_URL, params={
-            "acc": acc,
+            "accession": accession,
             "database": database
         }, headers=constants.HEADERS)
-        return res
+
+        if res.status_code != 200:
+            raise BadRequest("The request accession {} and database {} thrown connection error".format(accession, database), res.status_code, payload=None)
+
+        file_links = []
+        if res.json():
+            for file_link in res.json():
+                file_links.append(file_link)
+        return file_links
 
     @staticmethod
-    def get_similar(acc, database):
-        if not acc:
-            return VerifyUtils.empty_param_error("acc")
+    def get_similar(accession, database):
+        if not accession:
+            raise BadRequest("missing parameter accession", MISSING_PARAMETER, payload=None)
 
         if not database:
-            return VerifyUtils.empty_param_error("database")
+            raise BadRequest("missing parameter database", MISSING_PARAMETER, payload=None)
 
         res = requests.get(constants.SIMILAR_URL, params={
-            "acc": acc,
+            "accession": accession,
             "database": database
         }, headers=constants.HEADERS)
-        return res
 
+        if res.status_code != 200:
+            raise BadRequest("The request accession {} and database {} thrown connection error".format(accession, database), res.status_code, payload=None)
+        return DataSetResult.get_object_from_json(res.json())
 
-if __name__ == '__main__':
-    client = DatasetClient()
-    res = client.search("human")
-    print(res)
